==> sources_fancymenu_fabric_3.8.0_MC_1.19.2.jar: de/keksuccino/fancymenu/customization/element/elements/audio/SetAudioWeightScreen.java <==
package de.keksuccino.fancymenu.customization.element.elements.audio;

import de.keksuccino.fancymenu.util.LocalizationUtils;
import de.keksuccino.fancymenu.util.rendering.gui.GuiGraphics;
import de.keksuccino.fancymenu.util.rendering.ui.screen.CellScreen;
import de.keksuccino.fancymenu.util.rendering.ui.widget.slider.v2.RangeSlider;
import org.jetbrains.annotations.NotNull;
import java.util.Arrays;
import java.util.function.Consumer;
import net.minecraft.class_2561;
import net.minecraft.class_2583;

public class SetAudioWeightScreen extends CellScreen {
    protected Consumer<Float> callback;
    protected float current;
    protected RangeSlider weightSlider;
    protected LabelCell weightInfo;

    protected SetAudioWeightScreen(float preset, @NotNull Consumer<Float> callback) {
        super(class_2561.method_43471("fancymenu.elements.audio.set_weight"));
        this.current = Math.max(0.0f, preset);
        this.callback = callback;
    }

    @Override
    protected void initCells() {

        this.addStartEndSpacerCell();

        // Add info text about weights
        Arrays.asList(LocalizationUtils.splitLocalizedLines("fancymenu.elements.audio.manage_audios.weight_info")).forEach(component -> {
            this.addLabelCell(component.method_27661().method_10862(class_2583.field_24360.method_10978(true)));
        });

        this.addSpacerCell(20);

        this.weightSlider = new RangeSlider(0, 0, 20, 20, class_2561.method_43473(), 0.0D, 5.0D, this.current);
        this.weightSlider.setRoundingDecimalPlace(1);
        this.weightSlider.setLabelSupplier(consumes -> class_2561.method_43469("fancymenu.elements.audio.set_weight.weight",
                class_2561.method_43470(String.format("%.1f", this.current))));
        this.weightSlider.setSliderValueUpdateListener((slider1, valueDisplayText, value) -> {
            this.current = (float)((RangeSlider)slider1).getRangeValue();
        });
        this.addWidgetCell(this.weightSlider, true);

        this.addSpacerCell(20);

        this.weightInfo = this.addLabelCell(class_2561.method_43473());

        this.addStartEndSpacerCell();

    }

    @Override
    public void render(@NotNull GuiGraphics graphics, int mouseX, int mouseY, float partial) {

        super.render(graphics, mouseX, mouseY, partial);

        // Show appropriate info based on current weight value
        class_2561 info;
        if (this.current == 0.0f) {
            info = class_2561.method_43471("fancymenu.elements.audio.manage_audios.weight.zero");
        } else if (this.current < 1.0f) {
            info = class_2561.method_43471("fancymenu.elements.audio.manage_audios.weight.low");
        } else if (this.current == 1.0f) {
            info = class_2561.method_43471("fancymenu.elements.audio.manage_audios.weight.normal");
        } else {
            info = class_2561.method_43471("fancymenu.elements.audio.manage_audios.weight.high");
        }
        info = info.method_27661().method_10862(class_2583.field_24360.method_10978(true));
        this.weightInfo.setText(info);

    }

    @Override
    protected void onCancel() {
        this.callback.accept(null);
    }

    @Override
    protected void onDone() {
        this.callback.accept(this.current);
    }
}

==> sources_fancymenu_fabric_3.8.1_MC_1.21.10.jar: de/keksuccino/fancymenu/customization/element/elements/audio/SetAudioWeightScreen.java <==
package de.keksuccino.fancymenu.customization.element.elements.audio;

import de.keksuccino.fancymenu.util.LocalizationUtils;
import de.keksuccino.fancymenu.util.rendering.ui.screen.CellScreen;
import de.keksuccino.fancymenu.util.rendering.ui.tooltip.Tooltip;
import de.keksuccino.fancymenu.util.rendering.ui.tooltip.TooltipHandler;
import de.keksuccino.fancymenu.util.rendering.ui.widget.slider.v2.RangeSlider;
import org.jetbrains.annotations.NotNull;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.function.Consumer;
import net.minecraft.class_2561;
import net.minecraft.class_2583;
import net.minecraft.class_332;

// In SetAudioWeightScreen.java

public class SetAudioWeightScreen extends CellScreen {
    protected Consumer<Float> callback;
    protected float current;
    protected RangeSlider weightSlider;
    protected LabelCell weightInfo;

    protected SetAudioWeightScreen(float preset, @NotNull Consumer<Float> callback) {
        super(class_2561.method_43471("fancymenu.elements.audio.set_weight"));
        this.current = Math.max(0.0f, preset);
        this.callback = callback;
    }

    @Override
    protected void initCells() {

        this.addStartEndSpacerCell();

        // Add info text about weights
        Arrays.asList(LocalizationUtils.splitLocalizedLines("fancymenu.elements.audio.manage_audios.weight_info")).forEach(component -> {
            this.addLabelCell(component.method_27661().method_10862(class_2583.field_24360.method_10978(true)));
        });

        this.addSpacerCell(20);

        this.weightSlider = new RangeSlider(0, 0, 20, 20, class_2561.method_43473(), 0.0D, 5.0D, this.current);
        this.weightSlider.setRoundingDecimalPlace(1);
        this.weightSlider.setLabelSupplier(consumes -> class_2561.method_43469("fancymenu.elements.audio.set_weight.weight",
                class_2561.method_43470(String.format("%.1f", this.current))));
        this.weightSlider.setSliderValueUpdateListener((slider1, valueDisplayText, value) -> {
            this.current = (float)((RangeSlider)slider1).getRangeValue();
        });
        this.addWidgetCell(this.weightSlider, true);

        this.addSpacerCell(20);

        this.weightInfo = this.addLabelCell(class_2561.method_43473());

        this.addStartEndSpacerCell();

    }

    @Override
    public void method_25394(@NotNull class_332 graphics, int mouseX, int mouseY, float partial) {

        super.method_25394(graphics, mouseX, mouseY, partial);

        // Show appropriate info based on current weight value
        class_2561 info;
        if (this.current == 0.0f) {
            info = class_2561.method_43471("fancymenu.elements.audio.manage_audios.weight.zero");
        } else if (this.current < 1.0f) {
            info = class_2561.method_43471("fancymenu.elements.audio.manage_audios.weight.low");
        } else if (this.current == 1.0f) {
            info = class_2561.method_43471("fancymenu.elements.audio.manage_audios.weight.normal");
        } else {
            info = class_2561.method_43471("fancymenu.elements.audio.manage_audios.weight.high");
        }
        info = info.method_27661().method_10862(class_2583.field_24360.method_10978(true));
        this.weightInfo.setText(info);

    }

    @Override
    protected void onCancel() {
        this.callback.accept(null);
    }

    @Override
    protected void onDone() {
        this.callback.accept(this.current);
    }
}
